// VAMAS Module
// version 98.Dec.4

#pragma rtGlobals=1

Proc xzGetVAMASData()

	silent 1
	
	string/G S_filename
	
	// open file; read first line of file to use for filetype
	
	variable filenum
	string firstline
	open/R/D/P=Datafiles/M="Select VAMAS file" filenum
	open/R filenum as S_filename
	FReadline filenum, firstline
	close filenum
	
	print S_filename
	
	do
				
		if (strsearch(firstline,"VAMAS",0)==0)

			// VAMAS VMS file
			
			xzGetVAMASVMSData(S_filename)
			if (exists("wave0"))
				xzInputYWave("wave0")
				break
			else
				Abort "File format was not VAMAS VMS as expected."
			endif
		endif

		if (strsearch(firstline,"format_identifier",0)!=-1)

			//print "VMA"		
			// VAMAS VMA file
		
			xzGetVAMASVMAData(S_filename)
			if (exists("wave0"))
				xzInputYWave("wave0")
				break
			else
				Abort "File format was not VAMAS VMA as expected."
			endif
		endif

		if (strsearch(firstline,"Institute:",0)!=-1)

			//print "DES"		
			// VAMAS DES file
			
			xzGetVAMASDESData(S_filename)
			if (exists("wave0"))
				xzInputYWave("wave0")
				break
			else
				Abort "File format was not VAMAS DES as expected."
			endif
		endif
	
	while(1)
End

// ____________ Get the VAMAS DES Data
	
Proc xzGetVAMASDESData(Sfilename)
	string sfilename

	silent 1
			
	LoadWave/P=Datafiles/Q/A=wave/J/K=2/V={"\t,"," $",0,1} Sfilename

	string technique = ParseforStrinWave("technique",wave0,3)
	if (strlen(technique)==0)
		killwaves/A/Z
		return 0
	endif
	xzSetFileType(technique)
	
	variable eenergy, sstart, sstep, stime, nscans
	
	eenergy = str2num(ParseforStrinWave("excitation energy",wave0,1))
	sstart = str2num(ParseforStrinWave("abscissa start",wave0,1))
	sstep = str2num(ParseforStrinWave("abscissa increment",wave0,1))
	stime =  str2num(ParseforStrinWave("collection time",wave0,1))
	nscans =  str2num(ParseforStrinWave("scans completed",wave0,1))
	
	//print eenergy, sstart, sstep, stime, nscans
	
	string notestr
	variable where
	where = str2num(ParseforStrinWave("object name",wave0,2))
	notestr = "Object Name: " + wave1[where]
	where = str2num(ParseforStrinWave("date acquired",wave0,2))
	notestr += "\rDate Acquired: " +   wave1[where]
	notestr += "\r" + ParseforStrinWave("scan type",wave0,0)
	notestr += "\r" +  ParseforStrinWave("comment",wave0,0)

	//print notestr
	
	string alabel, olabel, datalabels
	
	alabel = ParseforStrinWave("abscissa label",wave0,3)
	olabel = ParseforStrinWave("ordinate label",wave0,3)
	
	//print alabel, olabel
	
	datalabels = alabel + " " + olabel
	where = str2num(ParseforStrinWave(datalabels,wave0,2))
	
	//print where
	//edit wave0, wave1, wave2
	
	killwaves/Z wave0, wave1, wave2
	
	LoadWave/Q/P=Datafiles/J/D/A=wave/K=0/V={" "," $",0,0}/L={0,(where+2),0,2,1} Sfilename
	
	//edit wave3
	//abort
	
	wave0/=(stime*nscans)
	if (cmpstr(technique,"XPS")==0)
		sstart = eenergy - sstart
		sstep*=-1
	endif
	SetScale/P x sstart,sstep,"", wave0
	
	// display wave0
	
	note wave0, notestr
End

// ______________ Get the VAMAS VMA data

Proc xzGetVAMASVMAData(sfilename)
	string sfilename
	
	silent 1
	
	LoadWave/Q/A=wave/J/K=2/V={"\t,"," $",0,1} sfilename
	
	string technique=""
	technique = ParseforStrinWave("(* technique *)",wave0,3)
	if (strlen(technique)==0)
		killwaves/A/Z
		return 0
	endif
	xzSetFileType(technique)
	
	variable eenergy, sstart, sstep, stime, nscans, npts, phis
	
	eenergy = str2num(ParseforStrinWave("(* analysis source characteristic energy *)",wave0,1))
	sstart = str2num(ParseforStrinWave("(* abscissa start *)",wave0,1))
	sstep = str2num(ParseforStrinWave("(* abscissa increment *)",wave0,1))
	stime =  str2num(ParseforStrinWave("(* signal collection time *)",wave0,1))
	nscans =  str2num(ParseforStrinWave("(* number of scans to compile this block *)",wave0,1))
	npts =  str2num(ParseforStrinWave("(* number of ordinate values *)",wave0,1))
	phis = str2num(ParseforStrinWave("(* analyser work function or acceptance energy of atom or ion *)",wave0,1))

	// print eenergy, sstart, sstep, stime, nscans, npts, phis
	
	string notestr
	notestr = "Block Identifier: " + ParseforStrinWave("(* block identifier *)",wave0,3)
	// notestr += "\r" + ParseforStrinWave("date acquired",wave0,3)
	notestr += "\r" + ParseforStrinWave("(* scan mode *)",wave0,3)
	// notestr += "\r" +  ParseforStrinWave("comment",wave0,0)

	//print notestr
	//print technique
	
	variable where
	where = str2num(ParseforStrinWave("(* ordinate value 1  *)",wave0,2))
	
	//print where
	
	killwaves/Z wave0
	
	LoadWave/Q/P=DataFiles/J/A=wave/K=2/V={" "," $",0,1}/L={0,where,npts,0,0} sfilename
	variable indx
	indx = CountofStrinList(S_wavenames,";")-1
	
	string wvn = "wave" + num2str(indx)
	make/n=(npts) tmpwave
	tmpwave = str2num($wvn)

	tmpwave/=(stime*nscans)
	if (cmpstr(technique,"XPS")==0)
		sstart = eenergy - sstart
		sstep*=-1
	endif
	SetScale/P x sstart,sstep,"", tmpwave
	
	// display tmpwave
	
	note tmpwave, notestr
	variable ic = 0
	do
		wvn = "wave" + num2str(ic)
		killwaves/Z $wvn
		ic += 1
	while (ic < indx)
	rename tmpwave wave0
End

// ______________ Get the VAMAS VMS data

Proc xzGetVAMASVMSData(sfilename)
	string sfilename
	
	silent 1
	
	LoadWave/P=DataFiles/Q/A=wave/J/K=2/L={0,0,61,0,0} sfilename
	
	string technique
	technique = wave0[25]
	if (strlen(technique)>6)
		string tsstr = "Is the technique really " + technique + "?"
		DoAlert 1, tsstr
		if (V_flag==2)
			killwaves/A/Z
			return 0
		endif
	endif
	xzSetFileType(technique)
	
	// get sample information

	string sp = " ", notestr
	notestr = "Sample ID: " + wave0[16]
	notestr += "\rAnalysis Date YYYY/MM/DD HH:MM: " + wave0[17] + "/" + wave0[18] + "/" + wave0[19]
	notestr += sp + wave0[20] + ":" + wave0[21]
	
	// get analysis parameters
	
	notestr += "\r" + wave0[25] + sp + wave0[26] + sp + wave0[33] + " Ep or RR " + wave0[34]
	notestr += "\rTAKEOFFANGLE:" + wave0[41]
	
	variable sourcee, phis, sstart, sstep, stime, nscans, npts
	
	sourcee = str2num(wave0[27])
	phis = str2num(wave0[36])
	sstart = str2num(wave0[47])
	sstep = str2num(wave0[48])
	stime =  str2num(wave0[53])
	nscans =  str2num(wave0[54])
	npts =  str2num(wave0[60])
	
	//print notestr
	//print sourcee, sstart, sstep, stime, nscans, npts
	//print technique
		
	killwaves/Z wave0
	LoadWave/Q/P=DataFiles/J/A=wave/K=1/L={0,63,npts,0,1} sfilename
	
	wave0/=(stime*nscans)
	if (cmpstr(technique,"XPS")==0)
		sstart = sourcee - sstart
		sstep*=-1
	endif
	SetScale/P x sstart,sstep,"", wave0
	
	note wave0, notestr
End
